Imports data on House of Commons and House of Lords bills.
bills(ID = NULL, amendments = FALSE, start_date = "1900-01-01",
end_date = Sys.Date(), extra_args = NULL, tidy = TRUE,
tidy_style = "snake_case", verbose = TRUE)hansard_bills(ID = NULL, amendments = FALSE, start_date = "1900-01-01",
end_date = Sys.Date(), extra_args = NULL, tidy = TRUE,
tidy_style = "snake_case", verbose = TRUE)
The ID of a given bill to return data on. If NULL,
returns all bills, subject to other parameters. Defaults to NULL.
If TRUE, returns all bills with amendments,
subject to other parameters. Defaults to FALSE.
Only includes bills introduced on or after this date.
Accepts character values in 'YYYY-MM-DD' format, and objects of
class Date, POSIXt, POSIXct, POSIXlt or
anything else that can be coerced to a date with as.Date().
Defaults to '1900-01-01'.
Only includes bills introduced on or before this date.
Accepts character values in 'YYYY-MM-DD' format, and objects of
class Date, POSIXt, POSIXct, POSIXlt or
anything else that can be coerced to a date with as.Date().
Defaults to the current system date.
Additional parameters and queries to pass to API. These
queries must be strings and start with "&". See the
API documentation
or the package vignette for more details. Defaults to NULL.
Logical parameter. If TRUE, fixes the variable names
in the tibble to remove special characters and superfluous text, and
converts the variable names to a consistent style. Defaults to TRUE.
The style to convert variable names to, if
tidy = TRUE. Accepts one of 'snake_case', 'camelCase'
and 'period.case'. Defaults to 'snake_case'.
If TRUE, returns data to console on the progress
of the API request. Defaults to TRUE.
A tibble with details on bills before the House of Lords and the House of Commons.
# NOT RUN {
x <- bills()
x <- bills(amendments=TRUE)
x <- bills(1719)
x <- bills(start_date ='2016-01-01')
# }
Run the code above in your browser using DataLab