commons_division_date: Returns a tibble with the dates of House of Commons divisions.
Description
Returns a tibble with the dates of House of Commons divisions.
Usage
commons_division_date(date = NULL, extra_args = NULL, tidy = TRUE,
tidy_style = "snake_case")
Arguments
date
Returns all divisions on a given date. Defaults to NULL.
extra_args
Additional parameters to pass to API. Defaults to NULL.
tidy
Fix the variable names in the tibble to remove special characters and superfluous text, and converts the variable names to a consistent style. Defaults to TRUE.
tidy_style
The style to convert variable names to, if tidy = TRUE. Accepts one of 'snake_case', 'camelCase' and 'period.case'. Defaults to 'snake_case'.
Value
A tibble with the dates of divisions in the House of Commons.
Examples
Run this code# NOT RUN {
x <- commons_division_date('2017-04-19')
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab