Learn R Programming

hansard (version 0.4.6)

epetition: Imports data on Epetitions

Description

Imports data on Epetitions

Usage

epetition(ID = NULL, by_constituency = FALSE, extra_args = NULL,
  tidy = TRUE, tidy_style = "snake_case")

Arguments

ID

The ID of a given petition. If NULL, returns all petitions. Defaults to NULL.

by_constituency

Accepts either TRUE or FALSE. If TRUE, provides a tibble with a breakdown of signatures for each petition, by constituency. Defaults to FALSE.

extra_args

Additional parameters to pass to API. Defaults to NULL.

tidy

Fix the variable names in the tibble to remove special characters and superfluous text, and converts the variable names to a consistent style. Defaults to TRUE.

tidy_style

The style to convert variable names to, if tidy = TRUE. Accepts one of 'snake_case', 'camelCase' and 'period.case'. Defaults to 'snake_case'.

Value

A tibble with details on electronic petitions submitted to parliament.

Examples

Run this code
# NOT RUN {
x <- epetition(ID = 706964, by_constituency=TRUE)

# }

Run the code above in your browser using DataLab