Learn R Programming

hansard (version 0.5.0)

lords_interests: Registered interests of members of the House of Lords

Description

Registered interests of members of the House of Lords

Usage

lords_interests(peer_id = NULL, extra_args = NULL, tidy = TRUE,
  tidy_style = "snake_case")

hansard_lords_interests(peer_id = NULL, extra_args = NULL, tidy = TRUE, tidy_style = "snake_case")

Arguments

peer_id

The ID of a member of the House of lords. If NULL, returns a tibble with all listed financial interests for all members. Defaults to NULL.

extra_args

Additional parameters to pass to API. Defaults to NULL.

tidy

Fix the variable names in the tibble to remove special characters and superfluous text, and converts the variable names to a consistent style. Defaults to TRUE.

tidy_style

The style to convert variable names to, if tidy = TRUE. Accepts one of 'snake_case', 'camelCase' and 'period.case'. Defaults to 'snake_case'.

Value

A tibble with details on the interests of peers in the House of Lords.