Learn R Programming

hansard (version 0.4.6)

research_topics_list: research_topics_list

Description

A list of Parliamentary Research Briefings topics.

A list of Parliamentary Research Briefings subtopics, grouped by topic.

A list of types of Parliamentary Research Briefings.

Usage

research_topics_list()

research_subtopics_list()

research_types_list()

Arguments

Value

A list with the different research topics available.

A list with the different research subtopics available.

A list with the different types of research briefings.

Examples

Run this code
# NOT RUN {
 
# }
# NOT RUN {
research_topics_list <- research_topics_list()
# }
# NOT RUN {
 
# }
# NOT RUN {
research_subtopics_list <- research_subtopics_list()

# }
# NOT RUN {
 
# }
# NOT RUN {
research_types_list <- research_types_list()

# }

Run the code above in your browser using DataLab