Learn R Programming

hansard (version 0.4.0)

sessions_info: sessions_info

Description

Imports data on Parliamentary Sessions. Note that due to the date format used by the API, if days==TRUE and the end_date and start_date parameters are not set to the default values, the function downloads all available data and then subsets the data frame between the two given dates.

Usage

sessions_info(days = FALSE, start_date = "1900-01-01",
  end_date = Sys.Date(), extra_args = NULL, tidy = TRUE)

Arguments

days

If TRUE, returns data for all available days. If FALSE, returns data on each parliamentary session. Defaults to FALSE.

start_date

The earliest date to include in the data frame. Defaults to '1900-01-01'.

end_date

The latest date to include in the data frame. Defaults to current system date.

extra_args

Additional parameters to pass to API. Defaults to NULL.

tidy

Fix the variable names in the data frame to remove extra characters, superfluous text and convert variable names to snake_case. Defaults to TRUE.

Examples

Run this code


x <- sessions_info(days=TRUE)

x <- sessions_info(days=FALSE)


Run the code above in your browser using DataLab