Learn R Programming

hansard (version 0.4.0)

all_answered_questions: all_answered_questions

Description

Imports data on answered parliamentary questions

Usage

all_answered_questions(mp_id = NULL, start_date = "1900-01-01",
  end_date = Sys.Date(), extra_args = NULL, tidy = TRUE)

Arguments

mp_id

Accepts a member ID, and returns a data frame with all available questions asked by that member. If NULL, returns a data frame with all available answered questions.

start_date

The earliest date to include in the data frame. Defaults to '1900-01-01'.

end_date

The latest date to include in the data frame. Defaults to current system date.

extra_args

Additional parameters to pass to API. Defaults to NULL.

tidy

Fix the variable names in the data frame to remove extra characters, superfluous text and convert variable names to snake_case. Defaults to TRUE.

Examples

Run this code


x <- all_answered_questions(4019)


Run the code above in your browser using DataLab