The ID of a given bill to return data on. If NULL, returns all bills, subject to other parameters. Defaults to NULL.
amendments
If TRUE, returns all bills with amendments. Defaults to FALSE.
start_date
The earliest date to include in the tibble. Defaults to '1900-01-01'. Accepts character values in 'YYYY-MM-DD' format, and objects of class Date, POSIXt, POSIXct, POSIXlt or anything else than can be coerced to a date with as.Date().
end_date
The latest date to include in the tibble. Defaults to current system date. Defaults to '1900-01-01'. Accepts character values in 'YYYY-MM-DD' format, and objects of class Date, POSIXt, POSIXct, POSIXlt or anything else than can be coerced to a date with as.Date().
extra_args
Additional parameters to pass to API. Defaults to NULL.
tidy
Fix the variable names in the tibble to remove special characters and superfluous text, and converts the variable names to a consistent style. Defaults to TRUE.
tidy_style
The style to convert variable names to, if tidy = TRUE. Accepts one of 'snake_case', 'camelCase' and 'period.case'. Defaults to 'snake_case'.
Value
A tibble with details on bills before the House of Lords and the House of Commons.