Description
Imports data on House of Commons and House of Lords bills
Returns a data frames with all possible bill stage types.
Usage
bills(ID = NULL, amendments = FALSE, start_date = "1900-01-01",
end_date = Sys.Date(), extra_args = NULL, tidy = TRUE)bill_stage_types(tidy = TRUE)
Arguments
ID
The ID of a given bill to return data on. If NULL, returns all bills, subject to other parameters. Defaults to NULL.
amendments
If TRUE, returns all bills with amendments. Defaults to FALSE.
start_date
The earliest date to include in the data frame. Defaults to '1900-01-01'.
end_date
The latest date to include in the data frame. Defaults to current system date.
extra_args
Additional parameters to pass to API. Defaults to NULL.
tidy
Fix the variable names in the data frame to remove extra characters, superfluous text and convert variable names to snake_case. Defaults to TRUE.
Examples
Run this code
x <- bills()
x <- bills(amendments=TRUE)
x <- bills(1719)
x <- bill_stage_types()
Run the code above in your browser using DataLab