commons_answered_questions: commons_answered_questions
Description
Imports data on House of Commons answered questions. If all parameters are left empty, imports all available answered questions in a data frame.
Usage
commons_answered_questions(answering_department = NULL, answered_by = NULL,
start_date = "1900-01-01", end_date = Sys.Date(), extra_args = NULL,
tidy = TRUE)
Arguments
answering_department
Returns a data frame with all answered questions in the House of Commons from the given department. Defaults to NULL.
answered_by
Returns a data frame with all answered questions in the House of Commons by the given MP. Defaults to NULL.
start_date
The earliest date to include in the data frame. Defaults to '1900-01-01'.
end_date
The latest date to include in the data frame. Defaults to current system date.
extra_args
Additional parameters to pass to API. Defaults to NULL.
tidy
Fix the variable names in the data frame to remove extra characters, superfluous text and convert variable names to snake_case. Defaults to TRUE.
Examples
Run this code
x <- commons_answered_questions(answering_department = 'health', answered_by = '4019')
Run the code above in your browser using DataLab