Learn R Programming

hansard (version 0.4.0)

commons_division_date: commons_division_date

Description

Returns a data frames with the dates of House of Commons divisions.

Usage

commons_division_date(date = NULL, extra_args = NULL, tidy = TRUE)

Arguments

date

Returns all divisions on a given date. Defaults to NULL.

extra_args

Additional parameters to pass to API. Defaults to NULL.

tidy

Fix the variable names in the data frame to remove extra characters, superfluous text and convert variable names to snake_case. Defaults to TRUE.

Examples

Run this code

x <- commons_division_date('2016-10-12')


Run the code above in your browser using DataLab