powered by
Returns a data frames with the dates of House of Commons divisions.
commons_division_date(date = NULL, extra_args = NULL, tidy = TRUE)
Returns all divisions on a given date. Defaults to NULL.
Additional parameters to pass to API. Defaults to NULL.
Fix the variable names in the data frame to remove extra characters, superfluous text and convert variable names to snake_case. Defaults to TRUE.
x <- commons_division_date('2016-10-12')
Run the code above in your browser using DataLab