Imports data on House of Commons divisions.
commons_divisions(division_id = NULL, summary = FALSE,
start_date = "1900-01-01", end_date = Sys.Date(), extra_args = NULL,
tidy = TRUE, tidy_style = "snake_case")hansard_commons_divisions(division_id = NULL, summary = FALSE,
start_date = "1900-01-01", end_date = Sys.Date(), extra_args = NULL,
tidy = TRUE, tidy_style = "snake_case")
The id of a particular vote. If empty, returns a tibble with information on all commons divisions, subject to all other parameters. Defaults to NULL.
If TRUE, returns a small tibble summarising a division outcome. Otherwise returns a tibble with details on how each MP voted. Has no effect if `division_id` is empty. Defaults to FALSE.
The earliest date to include in the tibble. Defaults to '1900-01-01'. Accepts character values in 'YYYY-MM-DD' format, and objects of class Date, POSIXt, POSIXct, POSIXlt or anything else than can be coerced to a date with as.Date().
The latest date to include in the tibble. Defaults to current system date. Defaults to current system date. Accepts character values in 'YYYY-MM-DD' format, and objects of class Date, POSIXt, POSIXct, POSIXlt or anything else than can be coerced to a date with as.Date().
Additional parameters to pass to API. Defaults to NULL.
Fix the variable names in the tibble to remove special characters and superfluous text, and converts the variable names to a consistent style. Removes extra URL data from voting type columns. Defaults to TRUE.
The style to convert variable names to, if tidy = TRUE. Accepts one of 'snake_case', 'camelCase' and 'period.case'. Defaults to 'snake_case'.
A tibble with the results of divisions in the House of Commons.
# NOT RUN {
x <- commons_divisions()
x <- commons_divisions(division_id = 694163, summary = FALSE)
# }
Run the code above in your browser using DataLab