commons_divisions: commons_divisions
Description
Imports data on House of Commons divisions.
Usage
commons_divisions(division_id = NULL, summary = FALSE,
start_date = "1900-01-01", end_date = Sys.Date(), extra_args = NULL,
tidy = TRUE)
Arguments
division_id
The id of a particular vote. If empty, returns a data frame with information on all commons divisions. Defaults to NULL.
summary
If TRUE, returns a small data frame summarising a division outcome. Otherwise returns a data frame with details on how each MP voted. Has no effect if `division_id` is empty. Defaults to FALSE.
start_date
The earliest date to include in the data frame, if calling all divisions. Defaults to '1900-01-01'.
end_date
The latest date to include in the data frame, if calling all divisions. Defaults to current system date.
extra_args
Additional parameters to pass to API. Defaults to NULL.
tidy
Fix the variable names in the data frame to remove extra characters, superfluous text and convert variable names to snake_case. Defaults to TRUE.
Examples
Run this code
x <- commons_divisions()
x <- commons_divisions(division_id = 694163, summary = FALSE)
Run the code above in your browser using DataLab