powered by
Imports data on House of Commons oral question times
commons_oral_question_times(session = NULL, question_id = NULL, extra_args = NULL, tidy = TRUE)
Accepts a session in format yyyy/yy (e.g. 2016/17) and returns a data frame of all oral question times from that session
Accepts a question time ID, and returns a data frame of that question time.
Additional parameters to pass to API. Defaults to NULL.
Fix the variable names in the data frame to remove extra characters, superfluous text and convert variable names to snake_case. Defaults to TRUE.
x <- commons_oral_question_times(session='2016/17', question_id='685697')
Run the code above in your browser using DataLab