Imports data on House of Commons oral questions
commons_oral_questions(mp_id = NULL, answering_department = NULL,
start_date = "1900-01-01", end_date = Sys.Date(), extra_args = NULL,
tidy = TRUE, tidy_style = "snake_case")The ID of a given MP. Defaults to NULL.
The department that answers a question
The earliest date to include in the tibble. Defaults to '1900-01-01'. Accepts character values in 'YYYY-MM-DD' format, and objects of class Date, POSIXt, POSIXct, POSIXlt or anything else than can be coerced to a date with as.Date().
The latest date to include in the tibble. Defaults to current system date. Defaults to '1900-01-01'. Accepts character values in 'YYYY-MM-DD' format, and objects of class Date, POSIXt, POSIXct, POSIXlt or anything else than can be coerced to a date with as.Date().
Additional parameters to pass to API. Defaults to NULL.
Fix the variable names in the tibble to remove special characters and superfluous text, and converts the variable names to a consistent style. Defaults to TRUE.
The style to convert variable names to, if tidy = TRUE. Accepts one of 'snake_case', 'camelCase' and 'period.case'. Defaults to 'snake_case'.
A tibble with details on all oral questions in the House of Commons.
all_answered_questions commons_answered_questions commons_oral_question_times commons_written_questions lords_written_questions mp_questions
# NOT RUN {
x <- commons_oral_questions(mp_id=4019, answering_department = 'education')
# }
Run the code above in your browser using DataLab