Learn R Programming

hansard (version 0.4.0)

early_day_motions: early_day_motions

Description

Imports data on early day motions

Usage

early_day_motions(edm_id = NULL, session = NULL,
  start_date = "1900-01-01", end_date = Sys.Date(), signatures = 1,
  extra_args = NULL, tidy = TRUE)

Arguments

edm_id

Accepts the ID number of an early day motion, and returns data on that motion. Note that EDM numbers reset each parliamentary session, so using this as the only parameter will return multiple early day motions. Defaults to NULL.

session

Accepts a parliamentary session, in yyyy/yy format. Defaults to NULL.

start_date

The earliest date to include in the data frame, if calling all early day motions. Defaults to '1900-01-01'.

end_date

The latest date to include in the data frame, if calling all early day motions. Defaults to current system date.

signatures

The minimum number of signatures required for inclusion in the data frame. Defaults to 1.

extra_args

Additional parameters to pass to API. Defaults to NULL.

tidy

Fix the variable names in the data frame to remove extra characters, superfluous text and convert variable names to snake_case. Defaults to TRUE.

Examples

Run this code


x <- early_day_motions(edm_id = 1073)

x <- early_day_motions(edm_id = 1073, session='2015/16')


Run the code above in your browser using DataLab