Learn R Programming

hansard (version 0.4.0)

epetition: epetition

Description

Imports data on Epetitions

Usage

epetition(ID = NULL, by_constituency = FALSE, extra_args = NULL,
  tidy = TRUE)

Arguments

ID

The ID of a given constituency. If NULL, returns all petitions. Defaults to NULL.

by_constituency

Accepts either TRUE or FALSE. If TRUE, provides a data frame with a breakdown of signatures for each petition, by constituency. Defaults to FALSE.

extra_args

Additional parameters to pass to API. Defaults to NULL.

tidy

Fix the variable names in the data frame to remove extra characters, superfluous text and convert variable names to snake_case. Defaults to TRUE.

Examples

Run this code

x <- epetition(ID = 706964, by_constituency=TRUE)


Run the code above in your browser using DataLab