powered by
Imports data on Epetitions
epetition(ID = NULL, by_constituency = FALSE, extra_args = NULL, tidy = TRUE)
The ID of a given constituency. If NULL, returns all petitions. Defaults to NULL.
Accepts either TRUE or FALSE. If TRUE, provides a data frame with a breakdown of signatures for each petition, by constituency. Defaults to FALSE.
Additional parameters to pass to API. Defaults to NULL.
Fix the variable names in the data frame to remove extra characters, superfluous text and convert variable names to snake_case. Defaults to TRUE.
x <- epetition(ID = 706964, by_constituency=TRUE)
Run the code above in your browser using DataLab