Learn R Programming

hansard (version 0.4.0)

hansard: hansard: Provides Easy Downloading Capabilities for the UK Parliament API

Description

Provides functions to request data from the data.parliament.uk APIs. Because of the structure of the data.parliament.uk API, there is a named function for each type of available data for ease of use. Functions for each new API will be added as and when they become available on data.parliament.uk. The package is intended to simplify pulling data from an API for users unfamiliar with APIs, and does not cover all possible functionality available through the API. The API is rate limited to returning 5500 rows per request.

Arguments

Details

For more details please see the vignette.