lords_attendance: lords_attendance
Description
Imports data on House of Lords attendance. Please note that the attendance data frames are not as tidy as some of the others that are accessible through this API.
Usage
lords_attendance(session_id = NULL, start_date = "1900-01-01",
end_date = Sys.Date(), extra_args = NULL, tidy = TRUE)
Arguments
session_id
The ID of the House of Lords session. If NULL, returns a list of all sessions. Defaults to NULL.
start_date
The earliest date to include in the data frame. Defaults to '1900-01-01'.
end_date
The latest date to include in the data frame. Defaults to current system date.
extra_args
Additional parameters to pass to API. Defaults to NULL.
tidy
Fix the variable names in the data frame to remove extra characters, superfluous text and convert variable names to snake_case. Defaults to TRUE.
Examples
Run this code
x <- lords_attendance(session_id = 706178)
Run the code above in your browser using DataLab