Registered interests of members of the House of Lords
lords_interests(peer_id = NULL, extra_args = NULL, tidy = TRUE,
tidy_style = "snake_case")hansard_lords_interests(peer_id = NULL, extra_args = NULL, tidy = TRUE,
tidy_style = "snake_case")
The ID of a member of the House of lords. If NULL, returns a tibble with all listed financial interests for all members. Defaults to NULL.
Additional parameters to pass to API. Defaults to NULL.
Fix the variable names in the tibble to remove special characters and superfluous text, and converts the variable names to a consistent style. Defaults to TRUE.
The style to convert variable names to, if tidy = TRUE. Accepts one of 'snake_case', 'camelCase' and 'period.case'. Defaults to 'snake_case'.
A tibble with details on the interests of peers in the House of Lords.