mp_questions: mp_questions
Description
Accepts an ID number for a member of the House of Commons, and returns a data frame of of all their oral and written questions.
Usage
mp_questions(mp_id, question_type = "all", start_date = "1900-01-01",
end_date = Sys.Date(), extra_args = NULL, tidy = TRUE)
Arguments
mp_id
The ID number of a member of the House of Commons.
question_type
Accepts the arguments 'all', 'oral' and 'written'. Defaults to 'all'.
start_date
The earliest date to include in the data frame. Defaults to '1900-01-01'.
end_date
The latest date to include in the data frame. Defaults to current system date.
extra_args
Additional parameters to pass to API. Defaults to NULL.
tidy
Fix the variable names in the data frame to remove extra characters, superfluous text and convert variable names to snake_case. Defaults to TRUE.
Examples
Run this code
x <- mp_questions(172, 'all')
Run the code above in your browser using DataLab