publication_logs: publication_logs
Description
Imports data on Publication Logs
Usage
publication_logs(ID = NULL, start_date = "1900-01-01",
end_date = Sys.Date(), extra_args = NULL, tidy = TRUE)
Arguments
ID
Publication ID. Defaults to NULL. If not null, requests a data frame with information on the given publication.
start_date
The earliest date to include in the data frame. Defaults to '1900-01-01'.
end_date
The latest date to include in the data frame. Defaults to current system date.
extra_args
Additional parameters to pass to API. Defaults to NULL.
tidy
Fix the variable names in the data frame to remove extra characters, superfluous text and convert variable names to snake_case. Defaults to TRUE.
Examples
Run this code
# x <- publication_logs(683267)
Run the code above in your browser using DataLab