Learn R Programming

hansard (version 0.4.0)

tv_programmes: tv_programmes

Description

Imports data on TV broadcasts. To import information on TV channel options,

Imports data on TV broadcasts. To import information on TV channel options,

Imports data on TV broadcasts

Usage

tv_programmes(legislature = NULL, start_date = "1900-01-01",
  end_date = Sys.Date(), extra_args = NULL, tidy = TRUE)

tv_clips(mp_id = NULL, start_date = "1900-01-01", end_date = Sys.Date(), extra_args = NULL, tidy = TRUE)

tv_channels(tidy = TRUE)

Arguments

legislature

Accepts one of either 'commons' or 'lords'. If NULL, returns all TV programmes for all chambers.

start_date

The earliest date to include in the data frame, if calling all divisions, using the date the question was tabled. Defaults to '1900-01-01'.

end_date

The latest date to include in the data frame, if calling all divisions, using the date the question was tabled. Defaults to current system date.

extra_args

Additional parameters to pass to API. Defaults to NULL.

tidy

Fix the variable names in the data frame to remove extra characters, superfluous text and convert variable names to snake_case. Defaults to TRUE.

mp_id

Accepts the ID of an MP or peer, and returns all clips featuring that MP or peer. If NULL, returns data on all available clips. Defaults to NULL.

Examples

Run this code


x <- tv_programmes('commons', start_date='2016-11-01')



x <- tv_clips(4591)

Run the code above in your browser using DataLab